==> jaguar_query-0.0.19.tar.gz: lib/src/core/statement/update_statement.dart <==
part of query;

class UpdateStatement implements Statement {
  String _tableName;

  final Map<String, dynamic> _values = {};

  final AndExpression _where = new AndExpression();

  UpdateStatement();

  UpdateStatement into(String tableName) {
    if (_tableName != null) {
      throw new Exception("Name already assigend!");
    }
    _tableName = tableName;
    return this;
  }

  UpdateStatement set(SetColumn column) {
    setValue(column._column, column._value);
    return this;
  }

  UpdateStatement setMany(List<SetColumn> columns) {
    columns.forEach((SetColumn column) {
      setValue(column._column, column._value);
    });
    return this;
  }

  UpdateStatement setValue<ValType>(String column, ValType value) {
    _values[column] = value;
    return this;
  }

  UpdateStatement setValues(Map<String, dynamic> values) {
    _values.addAll(values);
    return this;
  }

  UpdateStatement where(Expression exp) {
    _where.and(exp);
    return this;
  }

  UpdateStatement eq<T>(String column, T val) => where(q.eq<T>(column, val));

  UpdateStatement ne<T>(String column, T val) => where(q.ne<T>(column, val));

  UpdateStatement gt<T>(String column, T val) => where(q.gt<T>(column, val));

  UpdateStatement
      gtEq<T>(String column, T val) => where(q.gtEq<T>(column, val));

  UpdateStatement
      ltEq<T>(String column, T val) => where(q.ltEq<T>(column, val));

  UpdateStatement lt<T>(String column, T val) => where(q.lt<T>(column, val));

  UpdateStatement like(String column, String val) => where(q.like(column, val));

  UpdateStatement inBetween<T>(String column, T low, T high) =>
      where(q.inBetween<T>(column, low, high));

  String toSql() {
    StringBuffer sb = new StringBuffer();

    sb.write('UPDATE $_tableName SET ');

    sb.write(_values.keys
        .map((String key) => '$key=${_valToStr(_values[key])}')
        .join(', '));

    if (_where.length != 0) {
      sb.write(' WHERE ');
      sb.write(_where.toSql());
    }

    sb.write(';');

    return sb.toString();
  }
}

==> jaguar_query-0.0.23.tar.gz: lib/src/core/statement/update_statement.dart <==
part of query;

class UpdateStatement implements Statement {
  String _tableName;

  final Map<String, dynamic> _values = {};

  final AndExpression _where = new AndExpression();

  UpdateStatement();

  UpdateStatement into(String tableName) {
    if (_tableName != null) {
      throw new Exception("Name already assigend!");
    }
    _tableName = tableName;
    return this;
  }

  UpdateStatement set(SetColumn column) {
    setValue(column._column, column._value);
    return this;
  }

  UpdateStatement setMany(List<SetColumn> columns) {
    columns.forEach((SetColumn column) {
      setValue(column._column, column._value);
    });
    return this;
  }

  UpdateStatement setValue<ValType>(String column, ValType value) {
    _values[column] = value;
    return this;
  }

  UpdateStatement setValues(Map<String, dynamic> values) {
    _values.addAll(values);
    return this;
  }

  UpdateStatement where(Expression exp) {
    _where.and(exp);
    return this;
  }

  UpdateStatement eq<T>(String column, T val) => where(q.eq<T>(column, val));

  UpdateStatement ne<T>(String column, T val) => where(q.ne<T>(column, val));

  UpdateStatement gt<T>(String column, T val) => where(q.gt<T>(column, val));

  UpdateStatement gtEq<T>(String column, T val) =>
      where(q.gtEq<T>(column, val));

  UpdateStatement ltEq<T>(String column, T val) =>
      where(q.ltEq<T>(column, val));

  UpdateStatement lt<T>(String column, T val) => where(q.lt<T>(column, val));

  UpdateStatement like(String column, String val) => where(q.like(column, val));

  UpdateStatement inBetween<T>(String column, T low, T high) =>
      where(q.inBetween<T>(column, low, high));

  String toSql() {
    StringBuffer sb = new StringBuffer();

    sb.write('UPDATE $_tableName SET ');

    sb.write(_values.keys
        .map((String key) => '$key=${_valToStr(_values[key])}')
        .join(', '));

    if (_where.length != 0) {
      sb.write(' WHERE ');
      sb.write(_where.toSql());
    }

    sb.write(';');

    return sb.toString();
  }
}
